<?php
/*
 * Example of using API
 * sending invoices to clients for payment 
 */

// We initialize a class to work with API
require_once('flexbe_api.class.php');
$api_url = 'http://lp12345.myflexbe.com/mod/api/';
$api_key = 'ed677c52dccc04a456f846ebe06849b1';

$flexbe = new flexbeAPI($api_url,$api_key);

// Connection check
if ( !$flexbe->checkConnection() ) {
	print_r($flexbe->errors); 
	exit();
}

// We get 5 leads with the status "new"
// not older than 1 month, and not today's
$query_result = $flexbe->getLeads(array(
	'status' => 0, // 0- new, see $leads_statuses
	'start' => 0, 'count' => 5, // from 0 to 5

	// Date of lead creation more than one month ago
	'date_from'=>strtotime('-1 month'),
	// but less than today
	'date_to'=>strtotime('today UTC'),

	// Filter by client's phone number
	// 'client_phone'=>'16191234567',
	// Filter by client's email
	// 'client_email'=>'dev@flexbe.com',
));
$leads = $query_result['data']['leads'];


foreach ($leads as $lead_id => $lead) {
	/* 	
		Not to exceed the limit of requests per minute
		if we have many leads and requests are sent one by one in the cycle
		we make a pause
	*/
	if (count($leads) > 30) {
		sleep(1);
	}


	// Array of new information for a lead 
	$fields = array(); 


	// We set the status "in process"
	// if a lead is new
	if ($lead['status']['code']==0) {
		$fields['status'] = 1; // Status 1 - "In process" see $leads_statuses
	}

	// We add "edited" to the notes
	$fields['note'] = '[[ Edited through API '.date('d.m.Y H:i').' ]] '.$lead['note'];

	// We can change information about a contact
	/* $fields['client'] = array(
		'name'=>'Contact name',
		'phone'=>'16191234567',
		'email'=>'dev@flexbe.com',
	);*/

	// We add an invoice for payment
	// if there is none
	if (!is_array($lead['pay'])) {
		$fields['pay'] = array(
			'summ'=>'99.99', 	// invoice amount
			'status'=>0, 		// see $pays_statuses
			'desc'=>'Comment about the invoice for the user',
		);
	}

	// We call method of lead change
	$result = $flexbe->changeLead($lead['id'], $fields);

	// If everything is OK
	if ($result['status']==1) {
		// We send an email notification to the client
		// with a link to pay the invoice
		if (!empty($result['data']['pay']['pay_link']) && !empty($lead['client']['email'])) {
			$topic = 'You have received an invoice for payment';
			if (!empty($lead['client']['name'])) {
				$topic = $lead['client']['name'].', '.$topic;
			}
			
			$message = 'To see the invoice, follow this link: <br>
			<a href="'.$result['data']['pay']['pay_link'].'">'.$result['data']['pay']['pay_link'].'</a>';
			
			mail($lead['client']['email'], $topic, $message);
		}
	}

} // foreach ($leads ...