<?php 
/**
 *  Class to work with API flexbe.com
 *  
 *  @link http://flexbe.com/api/
 *  @author http://flexbe.com
 *  @package flexbe_api
 *  @version 1.0 
 */
class flexbeAPI {

	// Statuses of leads
	public $leads_statuses = array(
		0 => 'New',
		1 => 'In process',
		2 => 'Fulfilled',
		10 => 'Cancelled',
		11 => 'Deleted'
	);
	// Statuses of payment
	public $pays_statuses = array(
		0 => 'Pending payment',
		1 => 'In process',
		2 => 'Paid',
		3 => 'Payment error'
	);

	// Array with errors
	public $errors = array();

	// Parameters of connection to API (specified when the class is initialized)
	public $api_url = false;
	public $api_key = false;

	/**
	 *	Initialization
	 *	
	 *	@api_url string URL for requests to API
	 *	@api_key string secret access key to API
	 */	
	function __construct($api_url, $api_key) {
		$this->api_url = $api_url; 
		$this->api_key = $api_key;
	}
	
	// Check of API availability
	public function checkConnection(){
		$response = $this->query('checkConnection', array());
		if ( $response['status'] == 1 ) {
			return true;
		}
		return false;
	}

	/**
	 *	Call of method
	 *	
	 *	@method string getLeads|changeLead
	 *	@params array method parameters
	 */	
	public function query($method, $params=array()){
		$query_params = $params;
		$query_params['method'] = $method;
		$query_params['api_key'] = $this->api_key;

		$curl = curl_init($this->api_url);		
		curl_setopt_array($curl, array(
			CURLOPT_RETURNTRANSFER => true, 
			CURLOPT_POST => true,
			CURLOPT_POSTFIELDS => http_build_query($query_params)
		));
		$response_json = curl_exec($curl);
		$response = json_decode($response_json, true);

		if (is_array($response['error'])) {
			$this->errors[] = $response['error'];
		}

		return $response;
	}


	/**
	 *	Gettig leads
	 *	
	 *	@filter array method parameters
	 */	
	public function getLeads($filter=array()){
		return $this->query('getLeads', $filter);
	}


	/**
	 *	Changing a lead
	 *	
	 *	@id int lead identifier
	 *	@fields array changable fields
	 */	
	public function changeLead($id, $fields){
		$fields['id'] = $id;
		return $this->query('changeLead', $fields);
	}

}